@@ -36,8 +36,8 @@
 /**
  * Version of Biborb
  */
-$biborb_version = "1.3.2";
-$date_release = "26 October 2004";
+$biborb_version = "1.3.2-2";
+$date_release = "8 February 2005";
 
 /**
  * Name of the PHP SESSION
@@ -67,7 +67,7 @@ $disable_authentication = TRUE;
  * Authentication methods: mysql, files
  * Used if $disable_authentication = FALSE
  */
-$authentication_method = 'files';
+$authentication_method = 'mysql';
 
 /**
  *  Should a confirmation be displayed when deleting entries
@@ -190,5 +190,6 @@ $MAX_REFERENCES_BY_PAGE=10;
  * If true, each time a bibliography is modified, a BibTeX file is updated
  * in its 'bibs' directory.
  */
-$GEN_BIBTEX=TRUE
+$GEN_BIBTEX=TRUE;
+
 ?>
