@@ -744,8 +744,11 @@ function create_database($name,$description){
                       'error' => null);
     
     $databases_names = get_databases_names();
-    
-    if($name != null){
+     // check it is not a pathname
+    if(!ereg('^[^./][^/]*$', $name)){
+        $resArray['error'] = msg("Invalid name for bibliography!");
+    }
+    else if($name != null){
         if(!in_array($name,$databases_names)){
             $res = mkdir("./bibs/$name",0775);
             if($res){
@@ -762,7 +765,7 @@ function create_database($name,$description){
             chmod("./bibs/$name/$name.xml",0666);
             
             $fp = fopen("./bibs/$name/description.txt","w");
-            fwrite($fp,$description);
+            fwrite($fp,htmlentities($description));
             fclose($fp);
             $xml = load_file("./bibs/$name/$name.xml");
             $xml = str_replace("template",$name,$xml);
@@ -784,6 +787,10 @@ function create_database($name,$description){
     Delete a bibliography
  */
 function delete_database($name){
+     //check if $name is a valid bibliography name
+    if(!in_array($name,get_databases_names())){
+        die("Wrong database name!");
+    }
     // create .trash folder if it does not exit
     if(!file_exists("./bibs/.trash")){mkdir("./bibs/.trash",0775);}
     // save the bibto .trash folder
