@@ -750,7 +750,7 @@ function bibindex_display_by_group(){
  */
 function bibindex_display_search(){
 
-    $searchvalue = array_key_exists('search',$_GET) ? remove_accents(trim($_GET['search'])) :"";
+    $searchvalue = array_key_exists('search',$_GET) ? htmlentities(remove_accents(trim($_GET['search']))) :"";
     
     $title = msg("BIBINDEX_SIMPLE_SEARCH_TITLE");
     $html = bibheader();
@@ -992,7 +992,7 @@ function bibindex_display_advanced_search(){
     foreach($bibtex_fields as $field){
         $content .= "<label>".msg($field)."</label>";
         if(array_key_exists($field,$_GET)){
-            $thefield = remove_accents(trim($_GET[$field]));
+            $thefield = htmlentities(remove_accents(trim($_GET[$field])));
             $content .= "<input name='$field' value='".$thefield."'/>";
             $extraparam .= "$field=".$thefield."&";
         }
@@ -1005,7 +1005,7 @@ function bibindex_display_advanced_search(){
     foreach($biborb_fields as $field){
         $content .= "<label>".msg($field)."</label>";
         if(array_key_exists($field,$_GET)){
-            $thefield = remove_accents(trim($_GET[$field]));
+            $thefield = htmlentities(remove_accents(trim($_GET[$field])));
             $content .= "<input name='$field' value='".$thefield."'/>";
             $extraparam .= "$field=".$thefield."&";
         }
@@ -1025,14 +1025,14 @@ function bibindex_display_advanced_search(){
     
     $searchArray = array();
     foreach($bibtex_fields as $val){
-        if(array_key_exists($val,$_GET) && trim($_GET[$val]) != ''){
-            $searchArray['search_'.$val]=remove_accents(trim($_GET[$val]));
+        if(array_key_exists($val,$_GET) && trim(htmlentities($_GET[$val])) != ''){
+            $searchArray['search_'.$val]=htmlentities(remove_accents(trim($_GET[$val])));
         }
     }
     
     foreach($biborb_fields as $val){
         if(array_key_exists($val,$_GET) && trim($_GET[$val]) != ''){
-            $searchArray['search_'.$val]=remove_accents(trim($_GET[$val]));
+            $searchArray['search_'.$val]=htmlentities(remove_accents(trim($_GET[$val])));
         }
     }
     if(array_key_exists('connector',$_GET)){
